package com.bpcl.lpg.core.utill;

import org.slf4j.LoggerFactory;
import java.security.Key;
import java.util.Base64;
import javax.crypto.Cipher;
import javax.crypto.spec.SecretKeySpec;
import java.nio.charset.StandardCharsets;
import org.apache.commons.lang3.StringUtils;
import java.util.Objects;
import de.hybris.platform.servicelayer.dto.converter.ConversionException;
import de.hybris.platform.core.model.media.MediaFolderModel;
import java.io.DataInputStream;
import java.io.IOException;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.mock.web.MockMultipartFile;
import java.io.InputStream;
import org.apache.commons.io.IOUtils;
import java.io.FileInputStream;
import de.hybris.platform.core.model.media.MediaModel;
import java.io.File;
import de.hybris.platform.servicelayer.media.MediaService;
import de.hybris.platform.servicelayer.model.ModelService;
import org.slf4j.Logger;

public class LpgCashMemoUtil
{
    private static final Logger LOG;
    private static String errorDetails;
    private ModelService modelService;
    private MediaService mediaService;
    
    public ModelService getModelService() {
        return this.modelService;
    }
    
    public void setModelService(final ModelService modelService) {
        this.modelService = modelService;
    }
    
    public MediaService getMediaService() {
        return this.mediaService;
    }
    
    public void setMediaService(final MediaService mediaService) {
        this.mediaService = mediaService;
    }
    
    public boolean isNumeric(final String strNum, final int length, final String fieldName) {
        if (strNum == null || strNum.isEmpty()) {
            LpgCashMemoUtil.errorDetails = fieldName;
            return false;
        }
        if (strNum.length() != length && length != 0) {
            LpgCashMemoUtil.errorDetails = fieldName;
            return false;
        }
        try {
            Double.parseDouble(strNum);
        }
        catch (final Exception e) {
            return false;
        }
        return true;
    }
    
    public MediaModel converFileToMedia(final File file, final String fileType) throws IOException {
        String ContentType = "";
        if (fileType.equalsIgnoreCase("EXCEL")) {
            ContentType = "application/vnd.openxmlformats-officedocument.spreadsheetml.sheet";
        }
        else if (fileType.equalsIgnoreCase("PDF")) {
            ContentType = "application/pdf";
        }
        else if (fileType.equalsIgnoreCase("xml")) {
            ContentType = "application/xml";
        }
        else {
            ContentType = "text/csv";
        }
        final FileInputStream input = new FileInputStream(file);
        final MultipartFile multipartFile = (MultipartFile)new MockMultipartFile(file.getName(), file.getName(), ContentType, IOUtils.toByteArray(input));
        input.close();
        return this.createMedia(multipartFile);
    }
    
    private MediaModel createMedia(final MultipartFile multipartFile) {
        try {
            this.removeMediaIfPresent(multipartFile);
            final MediaModel media = (MediaModel)this.modelService.create((Class)MediaModel.class);
            media.setCode(multipartFile.getName());
            media.setMime(multipartFile.getContentType());
            media.setRealFileName(multipartFile.getOriginalFilename());
            this.modelService.save((Object)media);
            final DataInputStream dataInputStream = new DataInputStream(multipartFile.getInputStream());
            this.mediaService.setStreamForMedia(media, (InputStream)dataInputStream, media.getRealFileName(), media.getMime(), (MediaFolderModel)null);
            dataInputStream.close();
            return media;
        }
        catch (final Exception e) {
            LpgCashMemoUtil.LOG.info("PC transaction Report : Exception Occured while creating Media :", e);
            throw new ConversionException(" PC transaction Report : Exception Occured while creating Media  ", (Throwable)e);
        }
    }
    
    private void removeMediaIfPresent(final MultipartFile multipartFile) {
        try {
            final MediaModel file = this.mediaService.getMedia(multipartFile.getName());
            if (Objects.nonNull(file)) {
                this.modelService.remove((Object)file);
            }
        }
        catch (final Exception e) {
            LpgCashMemoUtil.LOG.info(" No Media found, now create new media with name: " + multipartFile.getName());
        }
    }
    
    public boolean isValidDeliveryBoy(final String strNum, final String fieldName) {
        if (strNum == null || strNum.isEmpty() || !strNum.startsWith("EO")) {
            LpgCashMemoUtil.errorDetails = fieldName;
            return false;
        }
        final String employeeCode = strNum.substring(2);
        return this.isNumeric(employeeCode, 14, fieldName);
    }
    
    public boolean isValidDate(final String data, final String fieldName) {
        final String re1 = "(\\d{4}[-/]\\d{1,2}[-/]\\d{1,2}\\s+((\\d{1,2}:\\d{1,2}:\\d{1,2}\\s+[AP]M)|(\\d{1,2}:\\d{1,2}:\\d{1,2})))|([0-9]{4}[-/][0-9]{1,2}[-/][0-9]{1,2})";
        final String re2 = "(\\d{1,2}[/]\\d{1,2}[/]\\d{4}\\s+\\d{1,2}:\\d{2}:\\d{2}\\s+[AP]M)|([0-9]{1,2}[/][0-9]{1,2}[/][0-9]{4})";
        if (data.matches("^((19|2[0-9])[0-9]{2})(0[1-9]|1[012])(0[1-9]|[12][0-9]|3[01])$") || data.matches(re2) || data.matches(re1)) {
            return true;
        }
        LpgCashMemoUtil.errorDetails = fieldName;
        return false;
    }
    
    public boolean isMobileNumber(final String strNum) {
        if (StringUtils.isEmpty((CharSequence)strNum)) {
            return false;
        }
        if (strNum.length() != 10) {
            return false;
        }
        if (Character.getNumericValue(strNum.charAt(0)) < 6) {
            return false;
        }
        try {
            Long.parseLong(strNum);
        }
        catch (final Exception exception) {
            return false;
        }
        return true;
    }
    
    public boolean isInt(final String strNum) {
        if (StringUtils.isEmpty((CharSequence)strNum)) {
            return false;
        }
        try {
            Long.parseLong(strNum);
        }
        catch (final Exception exception) {
            return false;
        }
        return true;
    }
    
    public static String encrypt(final String key, final String dataToEncrypt) {
        if (StringUtils.isNotBlank((CharSequence)key) && StringUtils.isNotBlank((CharSequence)dataToEncrypt)) {
            final Key aesKey = new SecretKeySpec(key.getBytes(StandardCharsets.UTF_8), "AES");
            Cipher cipher = null;
            try {
                cipher = Cipher.getInstance("AES/ECB/PKCS5Padding");
                cipher.init(1, aesKey);
                return Base64.getUrlEncoder().encodeToString(cipher.doFinal(dataToEncrypt.getBytes(StandardCharsets.UTF_8)));
            }
            catch (final Exception e) {
                LpgCashMemoUtil.LOG.error("Exception occurred while decrypting data: {} ", e.getMessage());
            }
        }
        return null;
    }
    
    public static String decrypt(final String key, final String encryptedData) {
        if (StringUtils.isNotBlank((CharSequence)key) && StringUtils.isNotBlank((CharSequence)encryptedData)) {
            final Key aesKey = new SecretKeySpec(key.getBytes(StandardCharsets.UTF_8), "AES");
            try {
                final Cipher cipher = Cipher.getInstance("AES/ECB/PKCS5Padding");
                cipher.init(2, aesKey);
                final byte[] decodedBytes = Base64.getUrlDecoder().decode(encryptedData);
                return new String(cipher.doFinal(decodedBytes), StandardCharsets.UTF_8);
            }
            catch (final Exception e) {
                LpgCashMemoUtil.LOG.error("Exception occurred while decrypting data: {} ", e.getMessage());
            }
        }
        return null;
    }
    
    static {
        LOG = LoggerFactory.getLogger(LpgCashMemoUtil.class);
        LpgCashMemoUtil.errorDetails = "";
    }
}
